@@ -49,8 +49,12 @@ Backupsets:
 
     has_backupset(backupset_name)   -- checks if a backupset exists with the given name or not
 
+    _process_add_response()         -- to process the add backupset request using API call
+
     add(backupset_name)             -- adds a new backupset to the agent of the specified client
 
+    add_salesforce_backupset()      -- adds a new salesforce backupset
+
     get(backupset_name)             -- returns the Backupset class object
     of the input backup set name
 
@@ -129,6 +133,7 @@ import threading
 import time
 import copy
 
+from base64 import b64encode
 from past.builtins import basestring
 
 from .subclient import Subclients
@@ -371,6 +376,55 @@ class Backupsets(object):
 
         return self._backupsets and backupset_name.lower() in self._backupsets
 
+    def _process_add_response(self, backupset_name, request_json):
+        """Runs the Backupset Add API with the request JSON provided,
+            and returns the contents after parsing the response.
+
+            Args:
+                backupset_name   (str)  --   backupset name
+                request_json    (dict)  --  JSON request to run for the API
+
+            Returns:
+                (bool, basestring, basestring):
+                    bool -  flag specifies whether success / failure
+
+                    str  -  error code received in the response
+
+                    str  -  error message received
+
+            Raises:
+                SDKException:
+                    if response is empty
+
+                    if response is not success
+        """
+        flag, response = self._cvpysdk_object.make_request('POST', self._services['ADD_BACKUPSET'], request_json)
+
+        if flag:
+            if response.json():
+                if 'response' in response.json():
+                    error_code = response.json()['response'][0]['errorCode']
+
+                    if error_code != 0:
+                        error_string = response.json()['response'][0]['errorString']
+                        o_str = 'Failed to create backupset\nError: "{0}"'.format(error_string)
+                        raise SDKException('Backupset', '102', o_str)
+                    else:
+                        # initialize the backupsets again
+                        # so the backupset object has all the backupsets
+                        self.refresh()
+                        return self.get(backupset_name)
+                elif 'errorMessage' in response.json():
+                    error_string = response.json()['errorMessage']
+                    o_str = 'Failed to create backuspet\nError: "{0}"'.format(error_string)
+                    raise SDKException('Backupset', '102', o_str)
+                else:
+                    raise SDKException('Response', '102')
+            else:
+                raise SDKException('Response', '102')
+        else:
+            raise SDKException('Response', '101', self._update_response_(response.text))
+
     def add(self, backupset_name, on_demand_backupset=False, **kwargs):
         """Adds a new backup set to the agent.
 
@@ -504,6 +558,113 @@ request_json['backupSetInfo'].update({
         else:
             raise SDKException('Response', '101', self._update_response_(response.text))
 
+    def add_salesforce_backupset(
+            self,
+            salesforce_options,
+            db_options=None, **kwargs):
+        """Adds a new Salesforce Backupset to the Commcell.
+
+            Args:
+
+                salesforce_options         (dict)       --  salesforce options
+                                                            {
+                                                                "salesforce_user_name": 'salesforce login user',
+                                                                "salesforce_user_password": 'salesforce user password',
+                                                                "salesforce_user_token": 'salesforce user token'
+                                                            }
+
+                db_options                 (dict)       --  database options to configure sync db
+                                                            {
+                                                                "db_enabled": 'True or False',
+                                                                "db_type": 'SQLSERVER or POSTGRESQL',
+                                                                "db_host_name": 'database hostname',
+                                                                "db_instance": 'database instance name',
+                                                                "db_name": 'database name',
+                                                                "db_port": 'port of the database',
+                                                                "db_user_name": 'database user name',
+                                                                "db_user_password": 'database user password'
+                                                            }
+
+                **kwargs                   (dict)       --     dict of keyword arguments as follows
+
+                                                            download_cache_path     (str)   -- download cache path
+                                                            mutual_auth_path        (str)   -- mutual auth cert path
+                                                            storage_policy          (str)   -- storage policy
+                                                            streams                 (int)   -- number of streams
+
+            Returns:
+                object  -   instance of the Backupset class for this new backupset
+
+            Raises:
+                SDKException:
+                    if backupset with given name already exists
+
+                    if failed to add the backupset
+
+                    if response is empty
+
+                    if response is not success
+        """
+
+        if db_options is None:
+            db_options = {'db_enabled': False}
+        if self.has_backupset(salesforce_options.get('salesforce_user_name')):
+            raise SDKException('Backupset', '102',
+                               'Backupset "{0}" already exists.'.format(salesforce_options.get('salesforce_user_name')))
+
+        salesforce_password = b64encode(salesforce_options.get('salesforce_user_password').encode()).decode()
+        salesforce_token = b64encode(salesforce_options.get('salesforce_user_token', '').encode()).decode()
+        db_user_password = ""
+        if db_options.get('db_enabled', False):
+            db_user_password = b64encode(db_options.get('db_user_password').encode()).decode()
+
+        request_json = {
+            "backupSetInfo": {
+                "backupSetEntity": {
+                    "clientName": self._client_object.client_name,
+                    "instanceName": self._instance_object.instance_name,
+                    "backupsetName": salesforce_options.get('salesforce_user_name'),
+                    "appName": self._agent_object.agent_name
+                },
+                "cloudAppsBackupset": {
+                    "instanceType": 3,
+                    "salesforceBackupSet": {
+                        "enableREST": True,
+                        "downloadCachePath": kwargs.get('download_cache_path', '/tmp'),
+                        "mutualAuthPath": kwargs.get('mutual_auth_path', ''),
+                        "token": salesforce_token,
+                        "userPassword": {
+                            "userName": salesforce_options.get('salesforce_user_name'),
+                            "password": salesforce_password,
+                        },
+                        "syncDatabase": {
+                            "dbEnabled": db_options.get('db_enabled', False),
+                            "dbPort": db_options.get('db_port', '1433'),
+                            "dbInstance": db_options.get('db_instance', ''),
+                            "dbName": db_options.get('db_name', self._instance_object.instance_name),
+                            "dbType": db_options.get('db_type', "SQLSERVER"),
+                            "dbHost": db_options.get('db_host_name', ''),
+                            "dbUserPassword": {
+                                "userName": db_options.get('db_user_name', ''),
+                                "password": db_user_password,
+
+                            },
+                        },
+                    },
+                    "generalCloudProperties": {
+                        "numberOfBackupStreams": kwargs.get('streams', 2),
+                        "storageDevice": {
+                            "dataBackupStoragePolicy": {
+                                "storagePolicyName": kwargs.get('storage_policy', '')
+                            },
+                        },
+                    },
+                },
+            },
+        }
+
+        self._process_add_response(salesforce_options.get('salesforce_user_name'), request_json)
+
     def get(self, backupset_name):
         """Returns a backupset object of the specified backupset name.
 
@@ -651,7 +812,26 @@ class Backupset(object):
         self._services = self._commcell_object._services
         self._update_response_ = self._commcell_object._update_response_
 
-        self._restore_methods = ['_process_restore_response', '_filter_paths', '_restore_json']
+        # self._restore_methods = ['_process_restore_response', '_filter_paths', '_restore_json']
+        self._restore_methods = [
+            '_process_restore_response',
+            '_filter_paths',
+            '_restore_json',
+            '_impersonation_json',
+            '_restore_browse_option_json',
+            '_restore_common_options_json',
+            '_restore_destination_json',
+            '_restore_fileoption_json',
+            '_json_restore_subtask'
+        ]
+
+        self._restore_options_json = [
+            '_impersonation_json_',
+            '_browse_restore_json',
+            '_destination_restore_json',
+            '_commonoption_restore_json',
+            '_fileoption_restore_json',
+        ]
 
         self._backupset_name = backupset_name.split('\\')[-1].lower()
         self._description = None
@@ -680,8 +860,8 @@ class Backupset(object):
         self._default_browse_options = {
             'operation': 'browse',
             'show_deleted': False,
-            'from_time': 0,         # value should either be the Epoch time or the Timestamp
-            'to_time': 0,           # value should either be the Epoch time or the Timestamp
+            'from_time': 0,  # value should either be the Epoch time or the Timestamp
+            'to_time': 0,  # value should either be the Epoch time or the Timestamp
             'path': '\\',
             'copy_precedence': 0,
             'media_agent': '',
@@ -706,6 +886,8 @@ class Backupset(object):
         """Returns the persistent attributes"""
         if attribute in self._restore_methods:
             return getattr(self._instance_object, attribute)
+        elif attribute in self._restore_options_json:
+            return getattr(self._instance_object, attribute)
 
         return super(Backupset, self).__getattribute__(attribute)
 
@@ -763,8 +945,6 @@ class Backupset(object):
                     self._plan = self._commcell_object.plans.get(
                         self._properties["planEntity"]["planName"]
                     )
-                else:
-                    self._plan = None
             else:
                 raise SDKException('Response', '102')
         else:
@@ -1080,7 +1260,7 @@ class Backupset(object):
         """Retrieves the items from browse response.
 
         Args:
-            result_set  (dict)  --  browse response dict obtained from server
+            result_set  (list of dict)  --  browse response dict obtained from server
 
         Returns:
             dict - Dictionary of the specified file with list of all the file versions and
@@ -1102,13 +1282,13 @@ class Backupset(object):
             path = result['path']
 
             if 'modificationTime' in result:
-                mod_time = time.localtime(result['modificationTime'])
+                mod_time = time.localtime(int(result['modificationTime']))
                 mod_time = time.strftime('%d/%m/%Y %H:%M:%S', mod_time)
             else:
                 mod_time = None
 
             if 'file' in result['flags']:
-                if result['flags']['file'] is True:
+                if result['flags']['file'] in (True, '1'):
                     file_or_folder = 'File'
                 else:
                     file_or_folder = 'Folder'
@@ -1201,19 +1381,21 @@ class Backupset(object):
                             break
 
                 if not browse_result:
-                    if 'messages' in response_json['browseResponses'][0]:
+                    try:
                         message = response_json['browseResponses'][0]['messages'][0]
                         error_message = message['errorMessage']
 
                         o_str = exception_message
                         raise SDKException('Subclient', '102', o_str.format(error_message))
-
-                    else:
+                    except KeyError:
                         return [], {}
 
                 if not result_set:
                     raise SDKException('Subclient', exception_code)
 
+                if not isinstance(result_set, list):
+                    result_set = [result_set]
+
                 if 'all_versions' in options['operation']:
                     return self._process_browse_all_versions_response(result_set)
 
@@ -1226,14 +1408,14 @@ class Backupset(object):
                     else:
                         path = '\\'.join([options['path'], name])
 
-                    if 'modificationTime' in result and result['modificationTime'] > 0:
-                        mod_time = time.localtime(result['modificationTime'])
+                    if 'modificationTime' in result and int(result['modificationTime']) > 0:
+                        mod_time = time.localtime(int(result['modificationTime']))
                         mod_time = time.strftime('%d/%m/%Y %H:%M:%S', mod_time)
                     else:
                         mod_time = None
 
                     if 'file' in result['flags']:
-                        if result['flags']['file'] is True:
+                        if result['flags']['file'] in (True, '1'):
                             file_or_folder = 'File'
                         else:
                             file_or_folder = 'Folder'
@@ -1395,11 +1577,10 @@ class Backupset(object):
 
             if output[0]:
                 return
-            else:
-                o_str = 'Failed to update the name of the backupset\nError: "{0}"'
-                raise SDKException('Backupset', '102', o_str.format(output[2]))
-        else:
-            raise SDKException('Backupset', '102', 'Backupset name should be a string value')
+            o_str = 'Failed to update the name of the backupset\nError: "{0}"'
+            raise SDKException('Backupset', '102', o_str.format(output[2]))
+
+        raise SDKException('Backupset', '102', 'Backupset name should be a string value')
 
     @description.setter
     def description(self, value):
@@ -1423,35 +1604,28 @@ class Backupset(object):
 
                 if output[0]:
                     return
-                else:
-                    o_str = 'Failed to update the description of the backupset\nError: "{0}"'
-                    raise SDKException('Backupset', '102', o_str.format(output[2]))
-            else:
-                raise SDKException(
-                    'Backupset', '102', 'Backupset description should be a string value'
-                )
-        else:
-            raise SDKException('Backupset', '102', 'Description cannot be modified')
+
+                o_str = 'Failed to update the description of the backupset\nError: "{0}"'
+                raise SDKException('Backupset', '102', o_str.format(output[2]))
+
+            raise SDKException(
+                'Backupset', '102', 'Backupset description should be a string value'
+            )
+
+        raise SDKException('Backupset', '102', 'Description cannot be modified')
 
     @plan.setter
     def plan(self, value):
         """Associates the plan to the backupset
 
-            Args:
-                value   (object)    --  the Plan object which is to be associated
-                                        with the backupset
-                
-                value   (str)       --  name of the plan which is to be associated
-                                        with the backupset
-
-                value   (None)      --  set value to None to remove plan associations
-
             Raises:
                 SDKException:
 
+                    if input value is not an instance of Plan class
+
                     if plan does not exist
 
-                    if plan association fails
+                    if plan associateion fails
 
                     if plan is not eligible to be associated
         """
@@ -1460,10 +1634,6 @@ class Backupset(object):
             plan_obj = value
         elif isinstance(value, basestring):
             plan_obj = self._commcell_object.plans.get(value)
-        elif value is None:
-            plan_obj = {
-                'planName': None
-            }
         else:
             raise SDKException('Backupset', '102', 'Input value is not of supported type')
 
@@ -1473,7 +1643,7 @@ class Backupset(object):
             'appId': int(self._agent_object.agent_id),
             'backupsetId': int(self.backupset_id)
         }
-        if value is not None and plan_obj.plan_name in plans_obj.get_eligible_plans(entity_dict):
+        if plan_obj.plan_name in plans_obj.get_eligible_plans(entity_dict):
             request_json = {
                 'backupsetProperties': {
                     'planEntity': {
@@ -1492,25 +1662,8 @@ class Backupset(object):
 
             if response[0]:
                 return
-            else:
-                o_str = 'Failed to asspciate plan to the backupset\nError: "{0}"'
-                raise SDKException('Backupset', '102', o_str.format(response[2]))
-        elif value is None:
-            request_json = {
-                'backupsetProperties': {
-                    'removePlanAssociation': True
-                }
-            }
-
-            response = self._process_update_reponse(
-                request_json
-            )
-
-            if response[0]:
-                return
-            else:
-                o_str = 'Failed to dissociate plan from backupset\nError: "{0}"'
-                raise SDKException('Backupset', '102', o_str.format(response[2]))
+            o_str = 'Failed to asspciate plan to the backupset\nError: "{0}"'
+            raise SDKException('Backupset', '102', o_str.format(response[2]))
         else:
             raise SDKException(
                 'Backupset',
@@ -1535,9 +1688,9 @@ class Backupset(object):
 
             if output[0]:
                 return
-            else:
-                o_str = 'Failed to set this as the Default Backup Set\nError: "{0}"'
-                raise SDKException('Backupset', '102', o_str.format(output[2]))
+
+            o_str = 'Failed to set this as the Default Backup Set\nError: "{0}"'
+            raise SDKException('Backupset', '102', o_str.format(output[2]))
 
     def backup(self):
         """Runs Incremental backup job for all subclients in this backupset.
@@ -1721,7 +1874,7 @@ class Backupset(object):
             'path': paths
         }
 
-        files, metadata = self._do_browse(options)
+        files, _ = self._do_browse(options)
 
         # Delete operation does not return any result, hence consider the operation successful
         if files:
