@@ -108,6 +108,8 @@ Commcell instance Attributes
     **commserv_version**        --  returns the ContentStore version installed on the `CommServ`,
     class instance is initalized for
 
+    **version**                 --  returns the complete version info of the commserv
+
     **commcell_id**             --  returns the `CommCell` ID
 
     **webconsole_hostname**     --  returns the host name of the `webconsole`,
@@ -216,17 +218,21 @@ Commcell instance Attributes
     perform backup network pairs operations on the commcell class
 
     **recovery_targets**        -- Returns the instance of RecoverTargets class
+
+    **reports**                 --  Return the instance of Report class
+
+    **job_management**          --  Returns an instance of the JobManagement class.
     
 """
 
 from __future__ import absolute_import
 from __future__ import unicode_literals
-from past.builtins import basestring
 
 import getpass
 import socket
 
 from base64 import b64encode
+from past.builtins import basestring
 
 from requests.exceptions import SSLError
 from requests.exceptions import Timeout
@@ -259,7 +265,7 @@ from .storage_pool import StoragePools
 from .monitoring import MonitoringPolicies
 from .policy import Policies
 from .schedules import SchedulePattern
-from .schedules import Schedule, Schedules
+from .schedules import Schedules
 from .activitycontrol import ActivityControl
 from .eventviewer import Events
 from .array_management import ArrayManagement
@@ -272,7 +278,9 @@ from .deployment.download import Download
 from .deployment.install import Install
 from .name_change import NameChange
 from .backup_network_pairs import BackupNetworkPairs
+from .reports import report
 from .recovery_targets import RecoveryTargets
+from .job import JobManagement
 
 USER_LOGGED_OUT_MESSAGE = 'User Logged Out. Please initialize the Commcell object again.'
 """str:     Message to be returned to the user, when trying the get the value of an attribute
@@ -429,6 +437,7 @@ class Commcell(object):
         self._commserv_timezone_name = None
         self._commserv_guid = None
         self._commserv_version = None
+        self._version_info = None
 
         self._id = None
         self._clients = None
@@ -465,8 +474,9 @@ class Commcell(object):
         self._registered_commcells = None
         self._redirect_rules_service = None
         self._backup_network_pairs = None
+        self._reports = None
         self._recovery_targets = None
-
+        self._job_management = None
         self.refresh()
 
         del self._password
@@ -551,6 +561,7 @@ class Commcell(object):
         del self._disaster_recovery
         del self._commcell_migration
         del self._backup_network_pairs
+        del self._job_management
         del self
 
     def _get_commserv_details(self):
@@ -581,6 +592,7 @@ class Commcell(object):
                     self._commserv_name = response.json()['commcell']['commCellName']
                     self._commserv_timezone_name = response.json()['csTimeZone']['TimeZoneName']
                     self._commserv_version = response.json()['currentSPVersion']
+                    self._version_info = response.json().get('csVersionInfo')
                     self._id = response.json()['commcell']['commCellId']
 
                     self._commserv_timezone = re.search(
@@ -624,6 +636,24 @@ class Commcell(object):
         else:
             raise SDKException('Response', '101', self._update_response_(response.text))
 
+    def qoperation_execute(self, request_xml):
+        """Wrapper for def _qoperation_execute(self, request_xml)
+
+            Args:
+                request_xml     (str)   --  request xml that is to be passed
+
+            Returns:
+                dict    -   JSON response received from the server.
+
+            Raises:
+                SDKException:
+                    if response is empty
+
+                    if response is not success
+        """
+
+        return self._qoperation_execute(request_xml)
+
     @staticmethod
     def _convert_days_to_epoch(days):
         """
@@ -739,9 +769,22 @@ class Commcell(object):
 
     @property
     def commserv_version(self):
-        """Returns the version installed on the CommServ."""
+        """Returns the version installed on the CommServ.
+
+            Example: 19
+
+        """
         return self._commserv_version
 
+    @property
+    def version(self):
+        """Returns the complete version info of the commserv
+
+            Example: 11 SP19.1
+
+        """
+        return self._version_info
+
     @property
     def webconsole_hostname(self):
         """Returns the value of the host name of the webconsole used to connect to the Commcell."""
@@ -1149,6 +1192,26 @@ class Commcell(object):
         except AttributeError:
             return USER_LOGGED_OUT_MESSAGE
 
+    @property
+    def reports(self):
+        """Returns the instance of the Report class"""
+        try:
+            if self._reports is None:
+                self._reports = report.Report(self)
+            return self._reports
+        except AttributeError:
+            return USER_LOGGED_OUT_MESSAGE
+
+    @property
+    def job_management(self):
+        """Returns the instance of the JobManagement class."""
+        try:
+            if not self._job_management:
+                self._job_management = JobManagement(self)
+            return self._job_management
+        except AttributeError:
+            return USER_LOGGED_OUT_MESSAGE
+
     def logout(self):
         """Logs out the user associated with the current instance."""
         if self._headers['Authtoken'] is None:
@@ -1386,7 +1449,7 @@ class Commcell(object):
                     raise SDKException('Commcell', '105', o_str)
 
                 elif "taskId" in response.json():
-                    return Schedules(self._commcell_object).get(task_id=response.json()['taskId'])
+                    return Schedules(self).get(task_id=response.json()['taskId'])
 
                 else:
                     raise SDKException('Commcell', '105')
@@ -2010,16 +2073,14 @@ class Commcell(object):
             registered_for_routing = 0
         xml_to_execute = """
         <EVGui_CN2CellRegReq>
-            <commcell isRegisteredForRouting="{0}" adminPwd="{1}" adminUsr="{2}" interfaceName="{3}" ccClientName="{4}">
-                <commCell commCellName="{5}" />
+            <commcell isRegisteredForRouting="{0}" adminPwd="{1}" adminUsr="{2}" interfaceName="{3}" ccClientName="{3}">
+                <commCell commCellName="{3}" />
             </commcell>
         </EVGui_CN2CellRegReq>
         """.format(
             registered_for_routing,
             admin_password,
             admin_username,
-            commcell_name,
-            commcell_name,
             commcell_name
         )
 
@@ -2145,4 +2206,4 @@ class Commcell(object):
 
         else:
             response_string = self._update_response_(response.text)
-            raise SDKException('Response', '101', response_string)
\ No newline at end of file
+            raise SDKException('Response', '101', response_string)
