@@ -71,8 +71,6 @@ Plan
 
     _update_plan_props()        -- method to update plan properties
 
-    _get_associated_entities()  -- method to get list of entities associated to a plan
-
     derive_and_add()            -- add new plan by deriving from the parent Plan object
 
     plan_name                   --  returns the name of the plan
@@ -102,8 +100,6 @@ Plan Attributes
     **schedule_policies**       --  returns the schedule policy of the plan
 
     **subclient_policy**        --  returns the subclient policy of the plan
-
-    **associated_entities**     --  returns all the backup entties associted with the plan
 """
 
 from __future__ import unicode_literals
@@ -395,7 +391,7 @@ class Plans(object):
     def add(self,
             plan_name,
             plan_sub_type,
-            storage_pool_name,
+            storage_pool_name=None,
             sla_in_minutes=240,
             override_entities=None):
         """Adds a new Plan to the CommCell.
@@ -411,6 +407,8 @@ class Plans(object):
 
                 "Laptop"    -   Laptop Plans
 
+                "ExchangeUser"  -   Exchange Mailbox Plan
+
 
             storage_pool_name   (str)   --  name of the storage pool to be used for the plan
 
@@ -451,27 +449,27 @@ class Plans(object):
 
         """
         if not (isinstance(plan_name, basestring) and
-                isinstance(plan_sub_type, basestring) and
-                isinstance(storage_pool_name, basestring)):
+                isinstance(plan_sub_type, basestring)):
             raise SDKException('Plan', '101')
         else:
             if self.has_plan(plan_name):
                 raise SDKException(
                     'Plan', '102', 'Plan "{0}" already exists'.format(plan_name)
                 )
-
-        storage_pool_id = int(self._commcell_object.storage_pools.get(
-            storage_pool_name).storage_pool_id)
+        if not plan_sub_type == 'ExchangeUser':
+            storage_pool_id = int(self._commcell_object.storage_pools.get(
+                storage_pool_name).storage_pool_id)
 
         request_json = self._get_plan_template(plan_sub_type, "MSP")
 
         request_json['plan']['summary']['slaInMinutes'] = sla_in_minutes
         request_json['plan']['summary']['description'] = "Created from CvPySDK."
         request_json['plan']['summary']['plan']['planName'] = plan_name
-        request_json['plan']['storage']['copy'][0]['dedupeFlags']['useGlobalDedupStore'] = 1
-        request_json['plan']['storage']['copy'][0]['useGlobalPolicy'] = {
-            "storagePolicyId": storage_pool_id
-        }
+        if not plan_sub_type == 'ExchangeUser':
+            request_json['plan']['storage']['copy'][0]['dedupeFlags']['useGlobalDedupStore'] = 1
+            request_json['plan']['storage']['copy'][0]['useGlobalPolicy'] = {
+                "storagePolicyId": storage_pool_id
+            }
         if plan_sub_type is "Server" and 'database' in request_json['plan']:
             request_json['plan']['database']['storageLog']['copy'][0]['dedupeFlags'][
                 'useGlobalDedupStore'] = 1
@@ -645,7 +643,6 @@ class Plan(object):
         self._override_entities = None
         self._parent_plan_id = None
         self._addons = []
-        self._associated_entities = {}
         self.refresh()
 
     def __repr__(self):
@@ -696,11 +693,15 @@ class Plan(object):
                 if 'subtype' in self._plan_properties['summary']:
                     self._subtype = self._plan_properties['summary']['subtype']
 
-                if 'copy' in self._plan_properties['storage']:
-                    for copy in self._plan_properties['storage']['copy']:
-                        if 'useGlobalPolicy' in copy:
-                            self._storage_pool = copy['useGlobalPolicy']
-                            break
+                if 'storage' in self._plan_properties:
+                    if 'copy' in self._plan_properties['storage']:
+                        for copy in self._plan_properties['storage']['copy']:
+                            if 'useGlobalPolicy' in copy:
+                                self._storage_pool = copy['useGlobalPolicy']
+                                break
+                    if 'storagePolicy' in self._plan_properties['storage']:
+                        self._child_policies['storagePolicy'] = self._plan_properties['storage'][
+                            'storagePolicy']['storagePolicyName']
 
                 if self._subtype == 33554439:
                     if 'clientGroup' in self._plan_properties['autoCreatedEntities']:
@@ -714,13 +715,11 @@ class Plan(object):
                         self._user_group = self._plan_properties['autoCreatedEntities'][
                             'localUserGroup']['userGroupName']
 
-                if 'storagePolicy' in self._plan_properties['storage']:
-                    self._child_policies['storagePolicy'] = self._plan_properties['storage'][
-                        'storagePolicy']['storagePolicyName']
 
-                if 'task' in self._plan_properties['schedule']:
-                    self._child_policies['schedulePolicy'] = self._plan_properties['schedule'][
-                        'task']['taskName']
+                if 'schedule' in self._plan_properties:
+                    if 'task' in self._plan_properties['schedule']:
+                        self._child_policies['schedulePolicy'] = self._plan_properties['schedule'][
+                            'task']['taskName']
 
                 if 'laptop' in self._plan_properties:
                     if 'backupContent' in self._plan_properties['laptop']['content']:
@@ -743,8 +742,6 @@ class Plan(object):
                 if 'parent' in self._plan_properties['summary']:
                     self._parent_plan_id = self._plan_properties['summary']['parent']['planId']
 
-                self._get_associated_entities()
-
                 return self._plan_properties
             else:
                 raise SDKException('Response', '102')
@@ -1044,31 +1041,6 @@ class Plan(object):
             response_string = self._commcell_object._update_response_(response.text)
             raise SDKException('Response', '101', response_string)
 
-    def _get_associated_entities(self):
-        """Gets all the backup entities associated with the plan.
-
-            Returns:
-                dict - dictionary containing list of entities that are
-                       associated with the plan.
-
-            Raises:
-                SDKException:
-                    if response is empty
-
-                    if response is not success
-        """
-        request_url = self._services['ASSOCIATED_ENTITIES'] % (self._plan_id)
-        flag, response = self._cvpysdk_object.make_request(
-            'GET', request_url
-        )
-
-        if flag:
-            if response.json() and 'entities' in response.json():
-                self._associated_entities = response.json()['entities']
-        else:
-            response_string = self._commcell_object._update_response_(response.text)
-            raise SDKException('Response', '101', response_string)
-
     @property
     def plan_id(self):
         """Treats the plan id as a read-only attribute."""
@@ -1190,11 +1162,6 @@ class Plan(object):
         """Treats the plan subclient policy as a read-only attribute"""
         return self._child_policies['subclientPolicyIds']
 
-    @property
-    def associated_entities(self):
-        """getter for the backup entities associated with the plan"""
-        return self._associated_entities
-
     def refresh(self):
         """Refresh the properties of the Plan."""
         self._properties = self._get_plan_properties()
