@@ -37,6 +37,10 @@ UsermailboxSubclient:
 
     restore_in_place()                  --  runs in-place restore for the subclient
 
+    set_pst_association()               --  Create PST assocaition for UserMailboxSubclient
+
+    set_fs_association_for_pst()        --  Helper method to create pst association for
+                                            PST Ingestion by FS association
 """
 
 
@@ -48,6 +52,10 @@ from ...exception import SDKException
 
 from ..exchsubclient import ExchangeSubclient
 
+from ...subclient import Subclients
+
+from ...backupset import Backupsets
+
 
 class UsermailboxSubclient(ExchangeSubclient):
     """Derived class from ExchangeSubclient Base class.
@@ -350,6 +358,8 @@ class UsermailboxSubclient(ExchangeSubclient):
                     archive_policy = None
                     cleanup_policy = None
                     retention_policy = None
+                    plan_name = None
+                    plan_id = None
                     display_name = str(child['userMailBoxInfo']['displayName'])
                     alias_name = str(child['userMailBoxInfo']['aliasName'])
                     smtp_address = str(child['userMailBoxInfo']['smtpAdrress'])
@@ -357,14 +367,17 @@ class UsermailboxSubclient(ExchangeSubclient):
                     exchange_server = str(child['userMailBoxInfo']['exchangeServer'])
                     user_guid = str(child['userMailBoxInfo']['user']['userGUID'])
                     is_auto_discover_user = str(child['userMailBoxInfo']['isAutoDiscoveredUser'])
-
-                    for policy in child['policies']['emailPolicies']:
-                        if policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 1:
-                            archive_policy = str(policy['policyEntity']['policyName'])
-                        elif policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 2:
-                            cleanup_policy = str(policy['policyEntity']['policyName'])
-                        elif policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 3:
-                            retention_policy = str(policy['policyEntity']['policyName'])
+                    if 'emailPolicies' in child['policies']:
+                        for policy in child['policies']['emailPolicies']:
+                            if policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 1:
+                                archive_policy = str(policy['policyEntity']['policyName'])
+                            elif policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 2:
+                                cleanup_policy = str(policy['policyEntity']['policyName'])
+                            elif policy['detail'].get('emailPolicy', {}).get('emailPolicyType') == 3:
+                                retention_policy = str(policy['policyEntity']['policyName'])
+                    if 'plan' in child:
+                        plan_name = child.get('plan').get('planName')
+                        plan_id = child.get('plan').get('planId')
 
                     temp_dict = {
                         'display_name': display_name,
@@ -376,7 +389,9 @@ class UsermailboxSubclient(ExchangeSubclient):
                         'is_auto_discover_user': is_auto_discover_user,
                         'archive_policy': archive_policy,
                         'cleanup_policy': cleanup_policy,
-                        'retention_policy': retention_policy
+                        'retention_policy': retention_policy,
+                        'plan_name': plan_name,
+                        'plan_id': plan_id
                     }
 
                     users.append(temp_dict)
@@ -585,7 +600,12 @@ class UsermailboxSubclient(ExchangeSubclient):
 
                         'pstTaskName' : "Task Name for PST",
 
-                        'folders' : ['list of folders'],
+                        'folders' : ['list of folders'] //If pst ingestion by folder location,
+                        'fsContent': Dictionary of client, backupset, subclient
+                        Ex: {'client1':{'backupset1':[subclient1], 'backupset2':None},
+                            'client2': None}
+                        This would add subclient1, all subclients under backupset2 and
+                        all backupsets under client2 to the association
 
                         'pstOwnerManagement' : {
 
@@ -596,7 +616,6 @@ class UsermailboxSubclient(ExchangeSubclient):
                             'usePSTNameToCreateChild': Boolean
                         }
                     }
-					
         """
         if not isinstance(subclient_content, dict):
             raise SDKException('Subclient', '101')
@@ -613,7 +632,6 @@ class UsermailboxSubclient(ExchangeSubclient):
             pst_dict = {
                 'pstTaskName': subclient_content['pstTaskName'],
                 'taskType': 1,
-                'folders':subclient_content['folders'],
                 'pstOwnerManagement': {
                     'adProperty': "",
                     'startingFolderPath': "",
@@ -633,7 +651,12 @@ class UsermailboxSubclient(ExchangeSubclient):
                         subclient_content["pstOwnerManagement"]["ownerSelectionOrder"]
                 }
             }
-
+            if 'folders' in subclient_content:
+                pst_dict['folders'] = subclient_content['folders']
+            elif 'fsContent' in subclient_content:
+                pst_dict['associations'] = self.set_fs_association_for_pst(
+                    subclient_content['fsContent'])
+                pst_dict['taskType'] = 0;
             subclient_entity = {"_type_": 7, "subclientId": int(self._subclient_id)}
             discover_info = {
                 'discoverByType': 9,
@@ -651,6 +674,62 @@ class UsermailboxSubclient(ExchangeSubclient):
         except KeyError as err:
             raise SDKException('Subclient', '102', '{} not given in content'.format(err))
 
+    def set_fs_association_for_pst(self, association):
+        """Helper method to create pst association for PST Ingestion by FS
+            Args:
+                association(dict) -- Dictionary of client, backupset, subclient
+                                    Ex: {'client1':{'backupset1':[subclient1], 'backupset2':None},
+                                        'client2': None}
+                                    This would add subclient1, all subclients under backupset2 and
+                                    all backupsets under client2 to the association
+        """
+        assoc_list = []
+        client_dict, backupset_dict, sub_dict = dict(), dict(), dict()
+        _type_id = {"client": 3, "subclient": 7, "backupset": 6, "apptype": 4}
+        for client_name, backupsets in association.items():
+            client_name = client_name.lower()
+            client_obj = self._commcell_object.clients.get(client_name)
+
+            client_dict = {"commCellId": int(self._commcell_object._id),
+                           "commcellName": self._commcell_object.commserv_name,
+                           "clientName": client_name,
+                           "clientId": int(client_obj.client_id)
+                           }
+            agent = client_obj.agents.get("file system")
+
+            if backupsets:
+                for backupset_name, subclients in backupsets.items():
+                    backupset_name = backupset_name.lower()
+                    backupset_obj = agent.backupsets.get(backupset_name)
+                    if not backupset_obj:
+                        raise SDKException('Subclient','102',"Backupset {0} not present in file "
+                                                             "system agent".format(backupset_name))
+                    backupset_dict = {"backupsetName": backupset_obj.name,
+                                      "appName": "File System",
+                                      "applicationId": int(agent.agent_id),
+                                      "backupsetId": int(backupset_obj.backupset_id),
+                                      "_type_": _type_id["backupset"]
+                                      }
+                    backupset_dict.update(client_dict)
+                    for subclient_name in subclients:
+                        if subclient_name not in backupset_obj.subclients.all_subclients:
+                            raise SDKException('Subclient','102',
+                                               "Subclient %s not present in backupset %s" %
+                                               (str(subclient_name), str(backupset_name)))
+                        subclient_name = subclient_name.lower()
+                        sub_dict = {"subclientId": int(backupset_obj.subclients.all_subclients[
+                                                           subclient_name]['id']),
+                                    "subclientName": subclient_name}
+                        sub_dict.update(backupset_dict)
+                        sub_dict["_type_"] = _type_id["subclient"]
+                        assoc_list.append(sub_dict)
+                    if not subclients:
+                        assoc_list.append(backupset_dict)
+            else:
+                client_dict["_type_"] = _type_id["client"]
+                assoc_list.append(client_dict)
+        return assoc_list
+
     def set_database_assocaition(self, subclient_content):
         """Create Database assocaition for UserMailboxSubclient.
 
@@ -987,6 +1066,50 @@ class UsermailboxSubclient(ExchangeSubclient):
         _assocaition_json_["emailAssociation"]["emailStatus"] = 2
         self._set_association_request(_assocaition_json_)
 
+    def enable_auto_discover_association(self, association_name, plan_name):
+        """Enable all users assocaition for UserMailboxSubclient.
+
+                    Args:
+                        association_name  (str)  --  Type of auto discover association
+                            Valid Values:
+                                "All Users"
+                                "All O365 Mailboxes"
+                                "All Public Folders"
+
+                        plan_name  (str)  --  Name of the plan to associate with users/groups
+
+
+                """
+        plan = self._commcell_object.plans.get(plan_name)
+
+        association_dict = {"All Users": 8,
+                            "All Office365 Groups": 11,
+                            "All Public Folders": 12
+                            }
+
+        _association_json = {
+            "emailAssociation": {
+                "emailStatus": 0,
+                "advanceOptions": {
+                    "enableAutoDiscovery": True
+                },
+                "subclientEntity": self._subClientEntity,
+                "emailDiscoverinfo": {
+                    "discoverByType": association_dict[association_name],
+                    "genericAssociations": [
+                        {
+                            "associationName": association_name,
+                            "associationType": association_dict[association_name]
+                        }
+                    ]
+                },
+                "plan": {
+                    "planId": int(plan.plan_id)
+                }
+            }
+        }
+        self._set_association_request(_association_json)
+
     def refresh(self):
         """Refresh the User Mailbox Subclient."""
         self._get_subclient_properties()
