@@ -90,8 +90,7 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
             copy_precedence=0,
             disk_option='Original',
             transport_mode='Auto',
-            proxy_client=None,
-            indexing_v2=False):
+            proxy_client=None):
         """Restores the FULL Virtual machine specified in the input list
             to the location same as the actual location of the VM in VCenter.
 
@@ -123,8 +122,6 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
                 proxy_client          (basestring)  --  proxy client to be used for restore
                                                         default: proxy added in subclient
 
-                indexing_v2           (boolean)     --  true if restore has to be performed from
-                                                        child vm for v2
 
             Returns:
                 object - instance of the Job class for this restore job
@@ -158,66 +155,22 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
 
         restore_option_copy = restore_option.copy()
 
-        if indexing_v2:
-            vm_to_restore = self._set_vm_to_restore(vm_to_restore)
-            job_objects = []
-            for eachvm in vm_to_restore:
-                restore_option = {}
-                restore_option = restore_option_copy.copy()
-                # set attr for all the option in restore xml from user inputs
-                self._set_restore_inputs(
-                    restore_option,
-                    vm_to_restore=[eachvm],
-                    in_place=True,
-                    esx_server_name="",
-                    volume_level_restore=1,
-                    unconditional_overwrite=overwrite,
-                    power_on=power_on,
-                    disk_option=disk_option_value,
-                    transport_mode=transport_mode_value,
-                    copy_precedence=copy_precedence
-                )
+        # set attr for all the option in restore xml from user inputs
+        self._set_restore_inputs(
+            restore_option,
+            vm_to_restore=self._set_vm_to_restore(vm_to_restore),
+            in_place=True,
+            esx_server_name="",
+            volume_level_restore=1,
+            unconditional_overwrite=overwrite,
+            power_on=power_on,
+            disk_option=disk_option_value,
+            transport_mode=transport_mode_value,
+            copy_precedence=copy_precedence
+        )
 
-                request_json = self._prepare_fullvm_restore_json(restore_option)
-                _vmclient_obj = self._commcell_object.clients.get(eachvm)
-                _vmagent_obj = _vmclient_obj.agents.get(self._agent_object._agent_name)
-                _vminstance_obj = _vmagent_obj.instances.get('VMInstance')
-                _vmbackupset_obj = _vminstance_obj.backupsets.get(
-                    self._backupset_object._backupset_name)
-                _vmsub_obj = _vmbackupset_obj.subclients.get('default')
-                request_json['taskInfo']['associations'][0]['clientName'] = eachvm
-                request_json['taskInfo']['associations'][0]['clientId'] = _vmsub_obj._subClientEntity[
-                    'clientId']
-                request_json['taskInfo']['associations'][0]['instanceName'] = 'VMInstance'
-                request_json['taskInfo']['associations'][0]['backupsetId'] = _vmsub_obj._subClientEntity[
-                    'backupsetId']
-                request_json['taskInfo']['associations'][0]['instanceId'] = _vmsub_obj._subClientEntity[
-                    'instanceId']
-                request_json['taskInfo']['associations'][0]['subclientGUID'] = _vmsub_obj._subClientEntity[
-                    'subclientGUID']
-                request_json['taskInfo']['associations'][0]['subclientName'] = 'default'
-                request_json['taskInfo']['associations'][0]['subclientId'] = _vmsub_obj._subClientEntity[
-                    'subclientId']
-                job_objects.append(self._process_restore_response(request_json))
-            return job_objects
-
-        else:
-            # set attr for all the option in restore xml from user inputs
-            self._set_restore_inputs(
-                restore_option,
-                vm_to_restore=self._set_vm_to_restore(vm_to_restore),
-                in_place=True,
-                esx_server_name="",
-                volume_level_restore=1,
-                unconditional_overwrite=overwrite,
-                power_on=power_on,
-                disk_option=disk_option_value,
-                transport_mode=transport_mode_value,
-                copy_precedence=copy_precedence
-            )
-
-            request_json = self._prepare_fullvm_restore_json(restore_option)
-            return self._process_restore_response(request_json)
+        request_json = self._prepare_fullvm_restore_json(restore_option)
+        return self._process_restore_response(request_json)
 
     def full_vm_restore_out_of_place(
             self,
@@ -234,8 +187,7 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
             proxy_client=None,
             source_ip=None,
             destination_ip=None,
-            network=None,
-            indexing_v2=False
+            network=None
     ):
         """Restores the FULL Virtual machine specified in the input list
             to the provided vcenter client along with the ESX and the datastores.
@@ -285,9 +237,6 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
 
                 network           (basestring)    --  Network of the detination vm
 
-                indexing_v2           (boolean)     --  true if restore has to be performed from
-                                                        child vm for v2
-
 
 
             Returns:
@@ -330,76 +279,28 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
 
         restore_option_copy = restore_option.copy()
 
-        if indexing_v2:
+        self._set_restore_inputs(
+            restore_option,
+            in_place=False,
+            vcenter_client=vcenter_client,
+            datastore=datastore,
+            esx_host=esx_host,
+            esx_server='',
+            unconditional_overwrite=overwrite,
+            power_on=power_on,
+            vm_to_restore=self._set_vm_to_restore(vm_to_restore),
+            disk_option=self._disk_option[disk_option],
+            transport_mode=self._transport_mode[transport_mode],
+            copy_precedence=copy_precedence,
+            volume_level_restore=1,
+            source_item=[],
+            source_ip=source_ip,
+            destination_ip=destination_ip,
+            network=network
+        )
 
-            vm_to_restore = self._set_vm_to_restore(vm_to_restore)
-            job_objects = []
-            for eachvm in vm_to_restore:
-                restore_option = {}
-                restore_option = restore_option_copy.copy()
-                self._set_restore_inputs(
-                    restore_option,
-                    in_place=False,
-                    vcenter_client=vcenter_client,
-                    datastore=datastore,
-                    esx_host=esx_host,
-                    esx_server='',
-                    unconditional_overwrite=overwrite,
-                    power_on=power_on,
-                    vm_to_restore=[eachvm],
-                    disk_option=self._disk_option[disk_option],
-                    transport_mode=self._transport_mode[transport_mode],
-                    copy_precedence=copy_precedence,
-                    volume_level_restore=1,
-                    source_item=[],
-                    source_ip=source_ip,
-                    destination_ip=destination_ip,
-                    network=network
-                )
-                request_json = self._prepare_fullvm_restore_json(restore_option)
-
-                _vmclient_obj = self._commcell_object.clients.get(eachvm)
-                _vmagent_obj = _vmclient_obj.agents.get(self._agent_object._agent_name)
-                _vminstance_obj = _vmagent_obj.instances.get('VMInstance')
-                _vmbackupset_obj = _vminstance_obj.backupsets.get(
-                    self._backupset_object._backupset_name)
-                _vmsub_obj = _vmbackupset_obj.subclients.get('default')
-
-                request_json['taskInfo']['associations'][0]['clientName'] = eachvm
-                request_json['taskInfo']['associations'][0]['clientId'] = _vmsub_obj._subClientEntity['clientId']
-                request_json['taskInfo']['associations'][0]['instanceName'] = 'VMInstance'
-                request_json['taskInfo']['associations'][0]['backupsetId'] = _vmsub_obj._subClientEntity['backupsetId']
-                request_json['taskInfo']['associations'][0]['instanceId'] = _vmsub_obj._subClientEntity['instanceId']
-                request_json['taskInfo']['associations'][0]['subclientGUID'] = _vmsub_obj._subClientEntity['subclientGUID']
-                request_json['taskInfo']['associations'][0]['subclientName'] = 'default'
-                request_json['taskInfo']['associations'][0]['subclientId'] = _vmsub_obj._subClientEntity['subclientId']
-                job_objects.append(self._process_restore_response(request_json))
-            return job_objects
-
-        else:
-
-            self._set_restore_inputs(
-                restore_option,
-                in_place=False,
-                vcenter_client=vcenter_client,
-                datastore=datastore,
-                esx_host=esx_host,
-                esx_server='',
-                unconditional_overwrite=overwrite,
-                power_on=power_on,
-                vm_to_restore=self._set_vm_to_restore(vm_to_restore),
-                disk_option=self._disk_option[disk_option],
-                transport_mode=self._transport_mode[transport_mode],
-                copy_precedence=copy_precedence,
-                volume_level_restore=1,
-                source_item=[],
-                source_ip=source_ip,
-                destination_ip=destination_ip,
-                network=network
-            )
-
-            request_json = self._prepare_fullvm_restore_json(restore_option)
-            return self._process_restore_response(request_json)
+        request_json = self._prepare_fullvm_restore_json(restore_option)
+        return self._process_restore_response(request_json)
 
     def disk_restore(self,
                      vm_name,
@@ -530,6 +431,118 @@ class VMWareVirtualServerSubclient(VirtualServerSubclient):
         request_json = self._prepare_disk_restore_json(_disk_restore_option)
         return self._process_restore_response(request_json)
 
+    def attach_disk_restore(self,
+                            vm_name,
+                            vcenter,
+                            esx=None,
+                            datastore=None,
+                            proxy_client=None,
+                            copy_precedence=0,
+                            media_agent=None,
+                            snap_proxy=None,
+                            disk_name=None):
+        """Attaches the Disks to the provided vm
+
+            Args:
+                vm_name             (basestring)    --  Name of the VM added in subclient content
+                                                        whose  disk is selected for restore
+
+                vcenter             (dict)          --  Dictinoary of vcenter, username and creds
+
+                esx                 (basestring)    --  Esx host where the vm resides
+
+                datastore               (string)    --  Datastore where disks will be restoed to
+                                                        default: None
+
+                proxy_client        (basestring)    --  Destination proxy client to be used
+                                                        default: None
+
+                copy_precedence            (int)    --  SP copy precedence from which browse has to
+                                                         be performed
+
+                media_agent                 (str)   -- MA needs to use for disk browse
+                    default :Storage policy MA
+
+                snap_proxy                   (str)   -- proxy need to be used for disk
+                                                    restores from snap
+                    default :proxy in instance or subclient
+
+                disk_name                    (str)  --  Prefix of the disk name to be attached
+                                                        defaul: None
+
+            Returns:
+                object - instance of the Job class for this restore job
+
+            Raises:
+                SDKException:
+                    if inputs are not passed in proper expected format
+
+                    if response is empty
+
+                    if response is not success
+        """
+
+        vm_names, vm_ids = self._get_vm_ids_and_names_dict_from_browse()
+        _attach_disk_restore_option = {}
+
+        disk_extn = '.vmdk'
+        if not disk_name:
+            disk_name = []
+        else:
+            disk_extn = self._get_disk_extension(disk_name)
+
+        # check if inputs are correct
+        if not (isinstance(vm_name, basestring) and
+                isinstance(disk_name, list) and
+                disk_extn == '.vmdk'):
+            raise SDKException('Subclient', '101')
+
+        if copy_precedence:
+            _attach_disk_restore_option['copy_precedence_applicable'] = True
+
+        # fetching all disks from the vm
+        disk_list, disk_info_dict = self.disk_level_browse(
+            "\\" + vm_ids[vm_name])
+
+        if not disk_name:   # if disk names are not provided, restore all vmdk disks
+            for each_disk_path in disk_list:
+                disk_name.append(each_disk_path.split('\\')[-1])
+
+        else:   # else, check if the given VM has a disk with the list of disks in disk_name.
+            for each_disk in disk_name:
+                each_disk_path = "\\" + str(vm_name) + "\\" + each_disk
+                if each_disk_path not in disk_list:
+                    raise SDKException('Subclient', '111')
+
+        if proxy_client is not None:
+            _attach_disk_restore_option['client'] = proxy_client
+        else:
+            _disk_restore_option['client'] = self._backupset_object._instance_object.co_ordinator
+
+        # set Source item List
+        src_item_list = []
+        for each_disk in disk_name:
+            src_item_list.append("\\" + vm_ids[vm_name] + "\\" + each_disk.split("\\")[-1])
+
+        _attach_disk_restore_option['paths'] = src_item_list
+
+        self._set_restore_inputs(
+            _attach_disk_restore_option,
+            in_place=True,
+            copy_precedence=copy_precedence,
+            vm_to_restore=vm_name,
+            esxHost=vcenter['vcenter'],
+            userName=vcenter['user'],
+            password=vcenter['password'],
+            esx=esx,
+            paths=src_item_list,
+            datastore=datastore,
+            volume_level_restore=6
+        )
+
+        request_json = self._prepare_attach_disk_restore_json(_attach_disk_restore_option)
+        return self._process_restore_response(request_json)
+
     def full_vm_conversion_azurerm(
             self,
             azure_client,
